PROGRAM check_namelist_files

!------------------------------------------------------------------------------!
! Current revisions:
! -----------------
!
!
! Former revisions:
! -----------------
! $Id: check_namelist_files.f90 932 2012-06-08 15:12:42Z maronga $
!
! 931 2012-06-08 15:09:28Z maronga
! Check of max_pr_user implemented
!
! 845 2012-03-07 10:23:05Z maronga
! Added call to init_cloud_physics
!
! 807 2012-01-25 11:53:51Z maronga
! Initial revision
!
! Description:
! ------------
! Perform namelist file check. The program is independent from PALM and used by 
! the shell script "mrun" to check the parameter files (e.g. p3d, p3df...) b
! efore the job is submitted/started. Source code from the PALM model in used in 
! check_namelist_files by means of the cpp directive "__check". The compiled
! program resides in the SCRIPTS folder as check_namelist_files.x.
!------------------------------------------------------------------------------!


    USE pegrid
    USE control_parameters

    IMPLICIT NONE


!
!-- Read number of processors, the variable check_restart and max_user_pr. 
!-- check_restart gives information whether the initalor the restart parameter
!-- file must be checked. max_user_pr is usually set by read_var_list
!-- (excluded in the namelist file check).
    READ (*,*,ERR=10,END=10)  numprocs, check_restart, max_pr_user
10  CONTINUE


!
!-- Read control parameters from NAMELIST files and read environment-variables1
    CALL parin

    OPEN( 11, FILE='parin_for_check', FORM='FORMATTED' )
    WRITE(11, FMT='(I)'), max_pr_user
    CLOSE(11)
!
!-- Determine processor topology and local array indicesy

    CALL init_pegrid

!
!-- Generate grid parameters
    CALL init_grid

!
!-- Check control parameters and deduce further quantities    
    CALL check_parameters

!
!-- Check absolute temperature and pressure. Delete this call in case that
!-- init_3d_model is compiled for the parameter file check
    CALL init_cloud_physics

 END PROGRAM check_namelist_files
